==> ecuacion-splib-web-1.73.14-sources.jar: jp/ecuacion/splib/web/bean/RedirectUrlOnSuccessPathBean.java <==
package jp.ecuacion.splib.web.bean;

import java.util.HashMap;
import java.util.Map;

public class RedirectUrlOnSuccessPathBean extends RedirectUrlOnSuccessBean {

  private String path;

  // public RedirectUrlPathBean(String path) {
  // this(path, new HashMap<>());
  // }

  // public RedirectUrlPathBean() {
  // this(new HashMap<>());
  // }

  public RedirectUrlOnSuccessPathBean(String path) {
    this(path, new HashMap<>());
  }

  // public RedirectUrlPathBean(Map<String, String> paramMap) {
  // this(null, true, paramMap);
  // }
  //
  // public RedirectUrlPathBean(String paramKey, String paramValue) {
  // this(null, true, paramKey, paramValue);
  // }
  //
  // public RedirectUrlPathBean(String[][] paramPairs) {
  // this(null, true, paramPairs);
  // }

  public RedirectUrlOnSuccessPathBean(String path, Map<String, String> paramMap) {
    this(path, true, paramMap);
  }

  public RedirectUrlOnSuccessPathBean(String path, String paramKey, String paramValue) {
    this(path, true, paramKey, paramValue);
  }

  public RedirectUrlOnSuccessPathBean(String path, String[][] paramPairs) {
    this(path, true, paramPairs);
  }

  // public RedirectUrlPathBean(boolean needsSuccessMesssage, Map<String, String> paramMap) {
  // this(null, needsSuccessMesssage, paramMap);
  // }
  //
  // public RedirectUrlPathBean(boolean needsSuccessMesssage, String paramKey, String paramValue) {
  // this(null, needsSuccessMesssage, paramKey, paramValue);
  // }
  //
  // public RedirectUrlPathBean(boolean needsSuccessMesssage, String[][] paramPairs) {
  // this(null, needsSuccessMesssage, paramPairs);
  // }

  public RedirectUrlOnSuccessPathBean(String path, boolean needsSuccessMesssage,
      Map<String, String> paramMap) {
    super(needsSuccessMesssage, paramMap);
    this.path = path;
  }

  public RedirectUrlOnSuccessPathBean(String path, boolean needsSuccessMesssage, String paramKey,
      String paramValue) {
    super(needsSuccessMesssage, paramKey, paramValue);
    this.path = path;
  }

  public RedirectUrlOnSuccessPathBean(String path, boolean needsSuccessMesssage,
      String[][] paramPairs) {
    super(needsSuccessMesssage, paramPairs);
    this.path = path;
  }

  public String getPath() {
    return path;
  }

  public void setPath(String path) {
    this.path = path;
  }

  public String getUrl() {
    String urlPath = "redirect:" + path + getParamsString();
    return urlPath;
  }
}

==> ecuacion-splib-web-1.75.0-sources.jar: jp/ecuacion/splib/web/bean/RedirectUrlOnSuccessPathBean.java <==
package jp.ecuacion.splib.web.bean;

import java.util.HashMap;
import java.util.Map;

public class RedirectUrlOnSuccessPathBean extends RedirectUrlOnSuccessBean {

  private String path;

  // public RedirectUrlPathBean(String path) {
  // this(path, new HashMap<>());
  // }

  // public RedirectUrlPathBean() {
  // this(new HashMap<>());
  // }

  public RedirectUrlOnSuccessPathBean(String path) {
    this(path, new HashMap<>());
  }

  // public RedirectUrlPathBean(Map<String, String> paramMap) {
  // this(null, true, paramMap);
  // }
  //
  // public RedirectUrlPathBean(String paramKey, String paramValue) {
  // this(null, true, paramKey, paramValue);
  // }
  //
  // public RedirectUrlPathBean(String[][] paramPairs) {
  // this(null, true, paramPairs);
  // }

  public RedirectUrlOnSuccessPathBean(String path, Map<String, String[]> paramMap) {
    this(path, true, paramMap);
  }

  public RedirectUrlOnSuccessPathBean(String path, String paramKey, String paramValue) {
    this(path, true, paramKey, paramValue);
  }

  public RedirectUrlOnSuccessPathBean(String path, String[][] paramPairs) {
    this(path, true, paramPairs);
  }

  // public RedirectUrlPathBean(boolean needsSuccessMesssage, Map<String, String> paramMap) {
  // this(null, needsSuccessMesssage, paramMap);
  // }
  //
  // public RedirectUrlPathBean(boolean needsSuccessMesssage, String paramKey, String paramValue) {
  // this(null, needsSuccessMesssage, paramKey, paramValue);
  // }
  //
  // public RedirectUrlPathBean(boolean needsSuccessMesssage, String[][] paramPairs) {
  // this(null, needsSuccessMesssage, paramPairs);
  // }

  public RedirectUrlOnSuccessPathBean(String path, boolean needsSuccessMesssage,
      Map<String, String[]> paramMap) {
    super(needsSuccessMesssage, paramMap);
    this.path = path;
  }

  public RedirectUrlOnSuccessPathBean(String path, boolean needsSuccessMesssage, String paramKey,
      String paramValue) {
    super(needsSuccessMesssage, paramKey, paramValue);
    this.path = path;
  }

  public RedirectUrlOnSuccessPathBean(String path, boolean needsSuccessMesssage,
      String[][] paramPairs) {
    super(needsSuccessMesssage, paramPairs);
    this.path = path;
  }

  public String getPath() {
    return path;
  }

  public void setPath(String path) {
    this.path = path;
  }

  public String getUrl() {
    String urlPath = "redirect:" + path + getParamsString();
    return urlPath;
  }
}
